==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOtherSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassAsAssociatedOtherSideSetImpl extends InstanceSet<ClassAsAssociatedOtherSideSet,ClassAsAssociatedOtherSide> implements ClassAsAssociatedOtherSideSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setTxt_Phrs( m_Txt_Phrs );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setCond( m_Cond );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setMult( m_Mult );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) referredtoclassinassocset.add( classasassociatedotherside.R204_is_a_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public LinkedAssociationSet R210_is_related_to_one_side_via_LinkedAssociation() throws XtumlException {
        LinkedAssociationSet linkedassociationset = new LinkedAssociationSetImpl();
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) linkedassociationset.add( classasassociatedotherside.R210_is_related_to_one_side_via_LinkedAssociation() );
        return linkedassociationset;
    }


    @Override
    public ClassAsAssociatedOtherSide nullElement() {
        return ClassAsAssociatedOtherSideImpl.EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

    @Override
    public ClassAsAssociatedOtherSideSet emptySet() {
      return new ClassAsAssociatedOtherSideSetImpl();
    }

    @Override
    public ClassAsAssociatedOtherSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsAssociatedOtherSide> elements() {
        return Arrays.asList(toArray(new ClassAsAssociatedOtherSide[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOtherSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassAsAssociatedOtherSideSetImpl extends InstanceSet<ClassAsAssociatedOtherSideSet,ClassAsAssociatedOtherSide> implements ClassAsAssociatedOtherSideSet {

    public ClassAsAssociatedOtherSideSetImpl() {
    }

    public ClassAsAssociatedOtherSideSetImpl(Comparator<? super ClassAsAssociatedOtherSide> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setTxt_Phrs( m_Txt_Phrs );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setCond( m_Cond );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setMult( m_Mult );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) classasassociatedotherside.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) referredtoclassinassocset.add( classasassociatedotherside.R204_is_a_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public LinkedAssociationSet R210_is_related_to_one_side_via_LinkedAssociation() throws XtumlException {
        LinkedAssociationSet linkedassociationset = new LinkedAssociationSetImpl();
        for ( ClassAsAssociatedOtherSide classasassociatedotherside : this ) linkedassociationset.add( classasassociatedotherside.R210_is_related_to_one_side_via_LinkedAssociation() );
        return linkedassociationset;
    }


    @Override
    public ClassAsAssociatedOtherSide nullElement() {
        return ClassAsAssociatedOtherSideImpl.EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

    @Override
    public ClassAsAssociatedOtherSideSet emptySet() {
      return new ClassAsAssociatedOtherSideSetImpl();
    }

    @Override
    public ClassAsAssociatedOtherSideSet emptySet(Comparator<? super ClassAsAssociatedOtherSide> comp) {
      return new ClassAsAssociatedOtherSideSetImpl(comp);
    }

    @Override
    public ClassAsAssociatedOtherSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsAssociatedOtherSide> elements() {
        return Arrays.asList(toArray(new ClassAsAssociatedOtherSide[0]));
    }

}
